﻿using System;
using System.Net;
using System.Reflection;
using System.Threading;
using System.Windows;
using System.Windows.Navigation;
using System.Windows.Threading;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            ServicePointManager.Expect100Continue = true;
            ServicePointManager.SecurityProtocol  = SecurityProtocolType.Ssl3 | SecurityProtocolType.Tls | SecurityProtocolType.Tls11 | SecurityProtocolType.Tls12;

            ServicePointManager.ServerCertificateValidationCallback = delegate { return true; };

            Loaded                     += Window_Loaded;
            this.newWindowButton.Click += newWindowButton_Click;
            this.browseButton.Click    += browseButton_Click;
            this.frame.Navigated       += frame_Navigated;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 윈도우 로드시 처리하기 - Window_Loaded(sender, e)

        /// <summary>
        /// 윈도우 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            this.frame.Source = new Uri("https://www.daum.net");
        }

        #endregion
        #region New Window 버튼 클릭시 처리하기 - newWindowButton_Click(sender, e)

        /// <summary>
        /// New Window 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void newWindowButton_Click(object sender, RoutedEventArgs e)
        {
            Thread thread = new Thread(ProcessNewWindow);

            thread.IsBackground = true;

            thread.SetApartmentState(ApartmentState.STA);

            thread.Start();
        }

        #endregion
        #region Browse 버튼 클릭시 처리하기 - browseButton_Click(sender, e)

        /// <summary>
        /// Browse 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void browseButton_Click(object sender, RoutedEventArgs e)
        {
            this.frame.Source = new Uri(this.newLocationTextBox.Text);
        }

        #endregion
        #region 프레임 이동 완료시 처리하기 - frame_Navigated(sender, e)

        /// <summary>
        /// 프레임 이동 완료시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void frame_Navigated(object sender, NavigationEventArgs e)
        {
            NavigationService navigationService = this.frame.NavigationService;

            dynamic browser = navigationService.GetType().GetField("_webBrowser", BindingFlags.NonPublic | BindingFlags.Instance).GetValue(navigationService);

            dynamic iWebBrowser2 = browser.GetType().GetField("_axIWebBrowser2", BindingFlags.NonPublic | BindingFlags.Instance).GetValue(browser);

            iWebBrowser2.Silent = true;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 새 윈도우 처리하기 - ProcessNewWindow()

        /// <summary>
        /// 새 윈도우 처리하기
        /// </summary>
        private void ProcessNewWindow()
        {
            MainWindow mainWindow = new MainWindow();

            mainWindow.Show();

            Dispatcher.Run();
        }

        #endregion
    }
}